@@ -1,9 +1,10 @@
 import logging
 
-from peek_core_user._private.PluginNames import userPluginFilt, \
-    userPluginActionProcessorName
-from peek_core_user._private.server.controller.MainController import \
-    MainController
+from peek_core_user._private.PluginNames import (
+    userPluginFilt,
+    userPluginActionProcessorName,
+)
+from peek_core_user._private.server.controller.MainController import MainController
 from vortex.handler.TupleActionProcessor import TupleActionProcessor
 
 logger = logging.getLogger(__name__)
@@ -13,5 +14,6 @@ def makeTupleActionProcessorHandler(mainController: MainController):
     processor = TupleActionProcessor(
         tupleActionProcessorName=userPluginActionProcessorName,
         additionalFilt=userPluginFilt,
-        defaultDelegate=mainController)
+        defaultDelegate=mainController,
+    )
     return processor
