@@ -5,8 +5,10 @@ from peek_core_user._private.storage.DeclarativeBase import loadStorageTuples
 from peek_core_user._private.tuples import loadPrivateTuples
 from peek_core_user.tuples import loadPublicTuples
 
-from peek_core_user._private.worker.tasks import UserImportInternalGroupTask, \
-    UserImportInternalUserTask
+from peek_core_user._private.worker.tasks import (
+    UserImportInternalGroupTask,
+    UserImportInternalUserTask,
+)
 
 logger = logging.getLogger(__name__)
 
@@ -30,6 +32,7 @@ class WorkerEntryHook(PluginWorkerEntryHookABC):
 
     @property
     def celeryAppIncludes(self):
-        return [UserImportInternalGroupTask.__name__,
-                UserImportInternalUserTask.__name__]
-
+        return [
+            UserImportInternalGroupTask.__name__,
+            UserImportInternalUserTask.__name__,
+        ]
